@@ -97,6 +97,7 @@ static void avcodecdecode_init(struct xlplayer *xlplayer)
          avcodecdecode_eject(xlplayer);
          xlplayer->playmode = PM_STOPPED;
          xlplayer->command = CMD_COMPLETE;
+         return;
          }
       if ((xlplayer->src_state = src_new(xlplayer->rsqual, self->c->channels, &src_error)), src_error)
          {
@@ -109,18 +110,22 @@ static void avcodecdecode_init(struct xlplayer *xlplayer)
          return;
          }
       }
+fprintf(stderr, "avcodecdecode_init: completed\n");
    }
    
 static void avcodecdecode_play(struct xlplayer *xlplayer)
    {
    struct avcodecdecode_vars *self = xlplayer->dec_data;
-   AVPacket pkt;
-   int size, out_size, len, frames, channels = self->c->channels;
+   AVPacket pkt, pktcopy;
+   int size, out_size, len, frames, channels = self->c->channels, ret;
    uint8_t *inbuf_ptr;
    SRC_DATA *src_data = &xlplayer->src_data;
    
-   if (av_read_frame(self->ic, &pkt) < 0 || (size = pkt.size) == 0)
+   if ((ret = av_read_frame(self->ic, &pkt)) < 0 || (size = pkt.size) == 0)
       {
+      if (pkt.data)
+         av_free_packet(&pkt);
+
       if (self->resample)	/* flush the resampler */
          {
          src_data->end_of_input = TRUE;
@@ -138,33 +143,44 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
       return;
       }
    inbuf_ptr = pkt.data;
-   
-   if (pkt.stream_index != self->stream)	/* discard video and audio not from the first audio stream */
+   pktcopy = pkt;
+
+   if (pkt.stream_index != self->stream)
       {
       if (pkt.data)
          av_free_packet(&pkt);
       return;
       }
-   
+
    while(size > 0 && xlplayer->command != CMD_EJECT)
       {
       out_size = AVCODEC_MAX_AUDIO_FRAME_SIZE;
       pthread_mutex_lock(&mutex);
-#ifdef DECODE_AUDIO_2
-      len = avcodec_decode_audio2(self->c, (short *)self->outbuf, &out_size, inbuf_ptr, size);
+#ifdef DECODE_AUDIO_3
+      len = avcodec_decode_audio3(self->c, (short *)self->outbuf, &out_size, &pktcopy);
 #else
-      len = avcodec_decode_audio(self->c, (short *)self->outbuf, &out_size, inbuf_ptr, size);
+      len = avcodec_decode_audio2(self->c, (short *)self->outbuf, &out_size, inbuf_ptr, size);
 #endif
       pthread_mutex_unlock(&mutex);
       frames = (out_size >> 1) / channels;
 
       if (len < 0)
+         {
+         fprintf(stderr, "avcodecdecode_play: error during decode\n");
          break;
+         }
+
+      pktcopy.data += len;
+      pktcopy.size -= len;
+      inbuf_ptr += len;
+      size -= len;
+
       if (out_size <= 0)
+         {
          continue;
+         }
 
       xlplayer_make_audio_to_float(xlplayer, self->floatsamples, self->outbuf, frames, 16, channels); 
-      
       if (self->resample)
          {
          src_data->input_frames = frames;
@@ -178,7 +194,6 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
          }
       else
          xlplayer_demux_channel_data(xlplayer, self->floatsamples, frames, channels, 1.f);
-      
       if (self->drop > 0)
          self->drop -= frames / (float)xlplayer->samplerate;
       else
@@ -187,12 +202,10 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
             xlplayer_write_channel_data(xlplayer);
             } while(xlplayer->write_deferred && xlplayer->command != CMD_EJECT);
          }
-
-      size -= len;
-      inbuf_ptr += len;
-      if (pkt.data)
-         av_free_packet(&pkt);
       }
+
+   if (pkt.data)
+      av_free_packet(&pkt);
    }
    
 int avcodecdecode_reg(struct xlplayer *xlplayer)
@@ -254,7 +267,7 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
       }
    pthread_mutex_unlock(&mutex);
     
-   self->outbuf = malloc(AVCODEC_MAX_AUDIO_FRAME_SIZE);
+   posix_memalign((void *)&self->outbuf, 64, AVCODEC_MAX_AUDIO_FRAME_SIZE);
    self->floatsamples = malloc(AVCODEC_MAX_AUDIO_FRAME_SIZE * 2);
    if (!self->outbuf || !self->floatsamples)
       {
@@ -267,6 +280,8 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
    xlplayer->dec_play = avcodecdecode_play;
    xlplayer->dec_eject = avcodecdecode_eject;
    
+fprintf(stderr, "avcodecdecode_reg: registered\n");
+
    return ACCEPTED;
    }
 
