@@ -17,6 +17,7 @@
 #   If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "../config.h"
 #include "gnusource.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -28,7 +29,11 @@
 #include "live_ogg_encoder.h"
 #include "live_mp3_encoder.h"
 #include "live_oggflac_encoder.h"
+#include "live_oggspeex_encoder.h"
 #include "bsdcompat.h"
+#ifdef DYN_LAME
+#include "dyn_lame.h"
+#endif
 
 #define RS_INPUT_SAMPLES 512
 
@@ -37,6 +42,21 @@ typedef jack_default_audio_sample_t sample_t;
 static const size_t rb_n_samples = 10000;	/* maximum number of samples to hold in the ring buffer */
 static uint32_t encoder_packet_magic_number = 'I' << 24 | 'D' << 16 | 'J' << 8 | 'C';
 
+int encoder_init_lame(struct threads_info *ti, struct universal_vars *uv, void *param)
+   {
+   int l = 1;
+
+#ifdef DYN_LAME
+   l = dyn_lame_init();
+#endif
+
+   printf("idjcsc: lame_available=%d\n", l);
+   fflush(stdout);
+   if (ferror(stdout))
+      return FAILED;
+   return SUCCEEDED;
+   }
+
 static enum data_format encoder_get_data_format(char *format, char *source)
    {
    if (!strcmp(format, "mp3"))
@@ -457,11 +477,9 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
    self->data_format = encoder_get_data_format(ev->format, ev->encode_source);
    switch (self->data_format)
       {
-#ifdef HAVE_LAME
       case DF_JACK_MP3:
          encoder_init = live_mp3_encoder_init;
          break;
-#endif /* HAVE_LAME */
       case DF_JACK_OGG:
          if (!strcmp(ev->subformat, "vorbis"))
             {
@@ -474,6 +492,13 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
             encoder_init = live_oggflac_encoder_init;
             break;
             }
+#endif
+#ifdef HAVE_SPEEX
+         if (!strcmp(ev->subformat, "speex"))
+            {
+            encoder_init = live_oggspeex_encoder_init;
+            break;
+            }
 #endif
       /*case DF_FILE_MP3:
          encoder_init = file_mp3_encoder_init;
