@@ -40,7 +40,6 @@
 #include "compressor.h"
 #include "xlplayer.h"
 #include "ialloc.h"
-#include "mp4tag.h"
 #include "speextag.h"
 #include "sndfileinfo.h"
 #include "avcodecdecode.h"
@@ -53,7 +52,7 @@
 #define FALSE 0
 
 /* playlength of ring buffer contents */
-#define RB_SIZE 1.0
+#define RB_SIZE 10.0
 /* number of samples in the fade (ring) buffer */
 #define FB_SIZE (RB_SIZE * sr)
 
@@ -88,6 +87,8 @@ int mic_filter;
 /* value of the stream mon. button */
 int stream_monitor = 0;
 /* when this is set the end of track alarm is started */
+int eot_alarm_set = 0;
+/* set when end of track alarm is active */
 int eot_alarm_f = 0;
 /* threshold values for a premature indicator that a player is about to finish */
 int jingles_samples_cutoff;
@@ -122,6 +123,8 @@ int mic_agc;
 struct agc *agc_left, *agc_right;
 /* flag for mp3 decode capability */
 int have_mad;
+/* size of the fade buffer */
+int fb_size;
 
 /* part of CTRL+C handling */
 sigset_t mixersigset;
@@ -221,9 +224,9 @@ char *mixer_string, *compressor_string, *gate_string, *microphone_string;
 char *normalizer_string, *new_mic_string;
 char *micl, *micr, *auxl, *auxr, *audl, *audr, *strl, *strr, *action;
 char *dol, *dor, *dil, *dir;
-char *oggpathname, *sndfilepathname, *mp4pathname, *mp4taglist, *avformatpathname, *speexpathname, *speextaglist, *speexcreatedby;
+char *oggpathname, *sndfilepathname, *avformatpathname, *speexpathname, *speextaglist, *speexcreatedby;
 char *playerpathname, *seek_s, *size, *playerplaylist, *loop, *resamplequality;
-char *agc_param;
+char *agc_param, *fade_mode;
 
 /* dictionary look-up type thing used by the parse routine */
 struct kvpdict kvpdict[] = {
@@ -250,12 +253,11 @@ struct kvpdict kvpdict[] = {
          { "DOR", &dor   },
          { "DIL", &dil   },
          { "DIR", &dir   },
+         { "FADE", &fade_mode },
          { "OGGP", &oggpathname },
-         { "MP4P", &mp4pathname },
          { "SPXP", &speexpathname },
          { "SNDP", &sndfilepathname },
          { "AVFP", &avformatpathname },
-         { "MP4T", &mp4taglist },
          { "SPXT", &speextaglist },
          { "SPXC", &speexcreatedby },
          { "RSQT", &resamplequality },
@@ -263,48 +265,6 @@ struct kvpdict kvpdict[] = {
          { "ACTN", &action },			/* Action to take */
          { "", NULL }};
 
-/* These two point to either sharp, mild, or NULL - optional mic hi-pass filter */   
-#if 0
-struct digital_filter *left_mic_filter;
-struct digital_filter *right_mic_filter;   
-
-/* variables for the various microphone filters */
-struct digital_filter *sharp_left_mic_filter;
-struct digital_filter *sharp_right_mic_filter;
-dfilter_t a_cheby100[] = { 1 , -4 , 6, -4, 1 };
-size_t a_cheby100_count = 5;
-dfilter_t b_cheby100[] = { 3.9418017792,-5.8274608161, 3.8294852689 ,-0.9438267667};
-size_t b_cheby100_count = 4;
-dfilter_t cheby100_filter_gain =1.029430476;
-
-struct digital_filter *mild_left_mic_filter;
-struct digital_filter *mild_right_mic_filter;
-dfilter_t a_butterworth90[] = { 1, -1 };
-size_t a_butterworth90_count = 2;
-dfilter_t b_butterworth90[] = { 0.9872586881 };
-size_t b_butterworth90_count = 1;
-dfilter_t butterworth90_filter_gain = 1.006411501;
-
-/* used for de-essing */
-struct digital_filter *ess_left_filter;
-struct digital_filter *ess_right_filter;
-dfilter_t a_ess8k12k[] = { 1, 0, -4, 0, 6, 0, -4, 0, 1 };
-size_t a_ess8k12k_count = 9;
-dfilter_t b_ess8k12k[] = { 1.0672882610,-3.4723263985,2.5984638141,-4.4589555851, 2.1983120838,-2.4940727230, 0.6389926185,-0.5067329547};
-size_t b_ess8k12k_count = 8;
-dfilter_t ess8k12k_gain = 5.472512765e+02;
- 
-/* used to produce a clean feed for the noisegate */
-struct digital_filter *ng_left_filter;
-struct digital_filter *ng_right_filter;
-dfilter_t a_ngbandpass[] = { 1, 0, -4, 0, 6, 0, -4, 0, 1 };
-size_t a_ngbandpasscount = 9;
-dfilter_t b_ngbandpass[] = { 7.0389284721, -21.9220056594, 39.5069302814, -45.1037888240, 33.4221059835, -15.7003351003, 4.2743904241, -0.5162255821 };
-size_t b_ngbandpasscount = 8;
-dfilter_t ngbandpassgain = 6.381624743e+02;
-#endif
-
-
 /* the rms filter currently in use */
 struct rms_calc *lm_rms_filter, *rm_rms_filter;
 
@@ -840,38 +800,38 @@ void process_audio(jack_nframes_t nframes)
          }
          /* end microphone mix */
 
-         if (plr_l->fadeindex != FB_SIZE)
+         if (plr_l->fadeindex < FB_SIZE)
             {
             lp_lc_fade = fade_table[plr_l->fadeindex] * *lplcpf++; 
             lp_rc_fade = fade_table[plr_l->fadeindex] * *lprcpf++;
-            plr_l->fadeindex++;
+            plr_l->fadeindex += plr_l->fadeoutstep;
             }
          else
             lp_lc_fade = lp_rc_fade = 0.0;
             
-         if (plr_r->fadeindex != FB_SIZE)
+         if (plr_r->fadeindex < FB_SIZE)
             {
             rp_lc_fade = fade_table[plr_r->fadeindex] * *rplcpf++; 
             rp_rc_fade = fade_table[plr_r->fadeindex] * *rprcpf++;
-            plr_r->fadeindex++;
+            plr_r->fadeindex += plr_r->fadeoutstep;
             }
          else
             rp_lc_fade = rp_rc_fade = 0.0;
          
-         if (plr_j->fadeindex != FB_SIZE)
+         if (plr_j->fadeindex < FB_SIZE)
             {
             jp_lc_fade = fade_table[plr_j->fadeindex] * *jplcpf++; 
             jp_rc_fade = fade_table[plr_j->fadeindex] * *jprcpf++;
-            plr_j->fadeindex++;
+            plr_j->fadeindex += plr_j->fadeoutstep;
             }
          else
             jp_lc_fade = jp_rc_fade = 0.0;
             
-         if (plr_i->fadeindex != FB_SIZE)
+         if (plr_i->fadeindex < FB_SIZE)
             {
             ip_lc_fade = fade_table[plr_i->fadeindex] * *iplcpf++; 
             ip_rc_fade = fade_table[plr_i->fadeindex] * *iprcpf++;
-            plr_i->fadeindex++;
+            plr_i->fadeindex += plr_i->fadeoutstep;
             }
          else
             ip_lc_fade = ip_rc_fade = 0.0;
@@ -1073,38 +1033,38 @@ void process_audio(jack_nframes_t nframes)
             /* No ducking */
             df = 1.0;
             
-            if (plr_l->fadeindex != FB_SIZE)
+            if (plr_l->fadeindex < FB_SIZE)
                {
                lp_lc_fade = fade_table[plr_l->fadeindex] * *lplcpf++; 
                lp_rc_fade = fade_table[plr_l->fadeindex] * *lprcpf++;
-               plr_l->fadeindex++;
+               plr_l->fadeindex += plr_l->fadeoutstep;
                }
             else
                lp_lc_fade = lp_rc_fade = 0.0;
                
-            if (plr_r->fadeindex != FB_SIZE)
+            if (plr_r->fadeindex < FB_SIZE)
                {
                rp_lc_fade = fade_table[plr_r->fadeindex] * *rplcpf++; 
                rp_rc_fade = fade_table[plr_r->fadeindex] * *rprcpf++;
-               plr_r->fadeindex++;
+               plr_r->fadeindex += plr_r->fadeoutstep;
                }
             else
                rp_lc_fade = rp_rc_fade = 0.0;
             
-            if (plr_j->fadeindex != FB_SIZE)
+            if (plr_j->fadeindex < FB_SIZE)
                {
                jp_lc_fade = fade_table[plr_j->fadeindex] * *jplcpf++; 
                jp_rc_fade = fade_table[plr_j->fadeindex] * *jprcpf++;
-               plr_j->fadeindex++;
+               plr_j->fadeindex += plr_j->fadeoutstep;
                }
             else
                jp_lc_fade = jp_rc_fade = 0.0;
-            
-            if (plr_i->fadeindex != FB_SIZE)
+               
+            if (plr_i->fadeindex < FB_SIZE)
                {
                ip_lc_fade = fade_table[plr_i->fadeindex] * *iplcpf++; 
                ip_rc_fade = fade_table[plr_i->fadeindex] * *iprcpf++;
-               plr_i->fadeindex++;
+               plr_i->fadeindex += plr_i->fadeoutstep;
                }
             else
                ip_lc_fade = ip_rc_fade = 0.0;
@@ -1311,42 +1271,42 @@ void process_audio(jack_nframes_t nframes)
                /* No ducking */
                df = 1.0;
                
-               if (plr_l->fadeindex != FB_SIZE)
+               if (plr_l->fadeindex < FB_SIZE)
                   {
                   lp_lc_fade = fade_table[plr_l->fadeindex] * *lplcpf++; 
                   lp_rc_fade = fade_table[plr_l->fadeindex] * *lprcpf++;
-                  plr_l->fadeindex++;
+                  plr_l->fadeindex += plr_l->fadeoutstep;
                   }
                else
                   lp_lc_fade = lp_rc_fade = 0.0;
                   
-               if (plr_r->fadeindex != FB_SIZE)
+               if (plr_r->fadeindex < FB_SIZE)
                   {
                   rp_lc_fade = fade_table[plr_r->fadeindex] * *rplcpf++; 
                   rp_rc_fade = fade_table[plr_r->fadeindex] * *rprcpf++;
-                  plr_r->fadeindex++;
+                  plr_r->fadeindex += plr_r->fadeoutstep;
                   }
                else
                   rp_lc_fade = rp_rc_fade = 0.0;
                
-               if (plr_j->fadeindex!= FB_SIZE)
+               if (plr_j->fadeindex < FB_SIZE)
                   {
                   jp_lc_fade = fade_table[plr_j->fadeindex] * *jplcpf++; 
                   jp_rc_fade = fade_table[plr_j->fadeindex] * *jprcpf++;
-                  plr_j->fadeindex++;
+                  plr_j->fadeindex += plr_j->fadeoutstep;
                   }
                else
                   jp_lc_fade = jp_rc_fade = 0.0;
-               
-               if (plr_i->fadeindex != FB_SIZE)
+                  
+               if (plr_i->fadeindex < FB_SIZE)
                   {
                   ip_lc_fade = fade_table[plr_i->fadeindex] * *iplcpf++; 
                   ip_rc_fade = fade_table[plr_i->fadeindex] * *iprcpf++;
-                  plr_i->fadeindex++;
+                  plr_i->fadeindex += plr_i->fadeoutstep;
                   }
                else
                   ip_lc_fade = ip_rc_fade = 0.0;
-               
+
                if (lmic_flux || rmic_flux || aux_flux)
                   update_mic_and_aux();		/* smooth mic rise and fall mute/unmute */
                
@@ -1558,42 +1518,42 @@ void process_audio(jack_nframes_t nframes)
                   }
                   /* end microphone mix */
                      
-                  if (plr_l->fadeindex != FB_SIZE)
+                  if (plr_l->fadeindex < FB_SIZE)
                      {
                      lp_lc_fade = fade_table[plr_l->fadeindex] * *lplcpf++; 
                      lp_rc_fade = fade_table[plr_l->fadeindex] * *lprcpf++;
-                     plr_l->fadeindex++;
+                     plr_l->fadeindex += plr_l->fadeoutstep;
                      }
                   else
                      lp_lc_fade = lp_rc_fade = 0.0;
                      
-                  if (plr_r->fadeindex != FB_SIZE)
+                  if (plr_r->fadeindex < FB_SIZE)
                      {
                      rp_lc_fade = fade_table[plr_r->fadeindex] * *rplcpf++; 
                      rp_rc_fade = fade_table[plr_r->fadeindex] * *rprcpf++;
-                     plr_r->fadeindex++;
+                     plr_r->fadeindex += plr_r->fadeoutstep;
                      }
                   else
                      rp_lc_fade = rp_rc_fade = 0.0;
                   
-                  if (plr_j->fadeindex!= FB_SIZE)
+                  if (plr_j->fadeindex < FB_SIZE)
                      {
                      jp_lc_fade = fade_table[plr_j->fadeindex] * *jplcpf++; 
                      jp_rc_fade = fade_table[plr_j->fadeindex] * *jprcpf++;
-                     plr_j->fadeindex++;
+                     plr_j->fadeindex += plr_j->fadeoutstep;
                      }
                   else
                      jp_lc_fade = jp_rc_fade = 0.0;
-
-                  if (plr_i->fadeindex != FB_SIZE)
+                     
+                  if (plr_i->fadeindex < FB_SIZE)
                      {
                      ip_lc_fade = fade_table[plr_i->fadeindex] * *iplcpf++; 
                      ip_rc_fade = fade_table[plr_i->fadeindex] * *iprcpf++;
-                     plr_i->fadeindex++;
+                     plr_i->fadeindex += plr_i->fadeoutstep;
                      }
                   else
                      ip_lc_fade = ip_rc_fade = 0.0;
-                  
+
                   if (lmic_flux || rmic_flux || aux_flux)
   	             update_mic_and_aux();	/* smooth mic rise and fall mute/unmute */
 
@@ -1934,14 +1894,9 @@ int main(int argc, char **argv)
       					JackPortIsInput, 0);
 
    sr = jack_get_sample_rate(client);
+   fb_size = FB_SIZE;
    jingles_samples_cutoff = sr / 12;		/* A twelfth of a second early */
    player_samples_cutoff = sr * 0.25;		/* for gapless playback */
-      
-   if(!(xlplayer_create_fadein_lookup(0.07F, sr)))
-      {
-      printf("failed to create the fadein lookup table for xlplayer\n");
-      return 1;
-      }
 
    if(! ((plr_l = xlplayer_create(sr, RB_SIZE, "leftplayer", &jack_closed_f)) &&
          (plr_r = xlplayer_create(sr, RB_SIZE, "rightplayer", &jack_closed_f))))
@@ -2004,6 +1959,7 @@ int main(int argc, char **argv)
       plr_i->fadeindex = FB_SIZE;
       for (i = 0; i < FB_SIZE; i ++)
          fade_table[i] = pow10f(i / -20000.0 * 44100.0 / FB_SIZE);
+         fade_table[i] = powf(fade_table[i], 0.1f);
       }
 
    if (!((agc_left = agc_init(sr, 0.01161f)) && (agc_right = agc_init(sr, 0.01161f))))
@@ -2094,6 +2050,12 @@ int main(int argc, char **argv)
          agc_valueparse(agc_right, agc_param);
          }
 
+      if (!strcmp(action, "fademode_left"))
+         plr_l->fade_mode = atoi(fade_mode);
+         
+      if (!strcmp(action, "fademode_right"))
+         plr_r->fade_mode = atoi(fade_mode);
+
       if (!strcmp(action, "playleft"))
          {
          fprintf(stdout, "context_id=%d\n", xlplayer_play(plr_l, playerpathname, atoi(seek_s), atoi(size)));
@@ -2173,15 +2135,6 @@ int main(int argc, char **argv)
       if (!strcmp(action, "sndfileinforequest"))
          sndfileinfo(sndfilepathname);
 
-#ifdef HAVE_MP4V2
-      if (!strcmp(action, "mp4inforequest"))
-         mp4_file_info(mp4pathname);
-      if (!strcmp(action, "mp4readtagrequest"))
-         mp4_tag_read(mp4pathname);
-      if (!strcmp(action, "mp4writetagrequest"))
-         mp4_tag_write(mp4pathname, mp4taglist);
-#endif
-
 #ifdef HAVE_AVCODEC
 #ifdef HAVE_AVFORMAT
       if (!strcmp(action, "avformatinforequest"))
@@ -2253,12 +2206,14 @@ int main(int argc, char **argv)
                 ":%03d:%03d:%03d:%03d:%03d:%d:%1d%1d%1d%1d%1d:%1d%1d:%1d%1d%1d:%1d%1d%1d%1d:%1d:%1d:%1d:%1d:%1d:%f:%f:%1d:%f:%d:%d:%d:",
       		&volume, &crossfade, &jinglesvolume, &interludevol, &mixbackvol, &jingles_playing,
                 &left_stream, &left_audio, &right_stream, &right_audio, &stream_monitor,
-		&new_left_pause, &new_right_pause, &lmic_on, &rmic_on, &aux_on, &flush_left, &flush_right, &flush_jingles, &flush_interlude, &simple_mixer, &eot_alarm_f, &mixermode, &fadeout_f, &main_play, &(plr_l->newpbspeed), &(plr_r->newpbspeed), &speed_variance, &dj_audio_level, &crosspattern, &use_dsp, &twodblimit) !=32)
+		&new_left_pause, &new_right_pause, &lmic_on, &rmic_on, &aux_on, &flush_left, &flush_right, &flush_jingles, &flush_interlude, &simple_mixer, &eot_alarm_set, &mixermode, &fadeout_f, &main_play, &(plr_l->newpbspeed), &(plr_r->newpbspeed), &speed_variance, &dj_audio_level, &crosspattern, &use_dsp, &twodblimit) !=32)
 	    {
 	    fprintf(stderr, "mixer got bad mixer string\n");
 	    break;
 	    }
 
+         eot_alarm_f |= eot_alarm_set;
+
          plr_l->fadeout_f = plr_r->fadeout_f = plr_j->fadeout_f = plr_i->fadeout_f = fadeout_f;
 
          if (use_dsp != using_dsp)
@@ -2497,6 +2452,7 @@ int main(int argc, char **argv)
 	 fflush(stdout);
          }
       }
+   alarm(0);
    jack_client_close(client);
    client = NULL;
    agc_free(agc_left);
@@ -2523,7 +2479,6 @@ int main(int argc, char **argv)
    xlplayer_destroy(plr_r);
    xlplayer_destroy(plr_j);
    xlplayer_destroy(plr_i);
-   xlplayer_destroy_fadein_lookup();
    fprintf(stderr, "Mixer module has closed\n");
    return 0;
    }
