@@ -151,7 +151,17 @@ static int decode_tit2(struct mp3taginfo *ti, unsigned char *start, struct chapt
       fprintf(stderr, "decode_tit2: unsupported character encoding\n");
       goto bailout;
       }
-   if (!(chap->text = malloc(chap->length = us.size - 1)))
+   if (us.data[us.size - 1])  /* handle potential null termination */
+      {
+      chap->length = us.size - 1;
+      fprintf(stderr, "not null terminated\n");
+      }
+   else
+      {
+      chap->length = us.size - 2;
+      fprintf(stderr, "null terminated\n");
+      }
+   if (!(chap->text = calloc(1, chap->length + 1)))
       goto bailout;
    memcpy(chap->text, us.data + 1, chap->length);
    free(us.data);
