@@ -27,6 +27,7 @@
 
 #define TIMESTAMP_SIZ 23
 
+#if 0
 static void recorder_write_ogg_metaheader(struct recorder *self)
    {
    struct encoder *encoder = self->encoder_op->encoder;
@@ -111,6 +112,7 @@ static void recorder_write_ogg_metaheader(struct recorder *self)
    vorbis_comment_clear(&vc);
    vorbis_info_clear(&vi);
    }
+#endif /* recorder_write_ogg_metaheader */
 
 static int recorder_write_id3_tag(struct recorder *self, FILE *fp)
    {
