@@ -44,10 +44,7 @@
 
 typedef jack_default_audio_sample_t sample_t;
 
-static sample_t *fadeinlookuptable;
-static size_t fadeinlookuptable_numsamples;
-
-extern int have_mad;
+extern int have_mad, fb_size;
 
 /* make_audio_to_float: convert the audio to the format used by jack and libsamplerate */
 float *xlplayer_make_audio_to_float(struct xlplayer *self, float *buffer, uint8_t *data, int num_samples, int bits_per_sample, int num_channels)
@@ -101,17 +98,17 @@ float *xlplayer_make_audio_to_float(struct xlplayer *self, float *buffer, uint8_
 /* used to fade in the audio when not starting from the beginning */
 sample_t xlplayer_get_next_gain(struct xlplayer *self)
    {
+   float val;
+   extern float *fade_table;
+
    if (self->fadein_index >= 0)
       {
-      if (self->fadein_index == fadeinlookuptable_numsamples)
-         {
-         self->fadein_index = -1;
-         return 1.0F;
-         }
-      return fadeinlookuptable[self->fadein_index++];
+      val = fade_table[self->fadein_index];
+      self->fadein_index -= self->fadeinstep;
+      return val;
       }
    else
-      return 1.0F;
+      return 1.0f;
    }
 
 /* xlplayer_demux_channel_data: this is where down/upmixing is performed - audio split to 2 channels */
@@ -225,8 +222,9 @@ static u_int32_t xlplayer_update_progress_time_ms(struct xlplayer *self)
    int32_t rb_time_ms;  /* the amount of time it would take to play all the samples in the buffer */
    int32_t progress;
    
-   rb_time_ms = jack_ringbuffer_read_space(self->right_ch) / sizeof (sample_t) * 1000 / self->samplerate;
-   progress = self->samples_written * 1000 / self->samplerate - rb_time_ms + self->seek_s * 1000;
+   rb_time_ms = (float)jack_ringbuffer_read_space(self->right_ch) / sizeof (sample_t) * 1000.0f / self->samplerate;
+   progress = self->samples_written * 1000.0f / self->samplerate - rb_time_ms + self->seek_s * 1000.0f;
+
    if (progress >= 0)
       return self->play_progress_ms = progress;
    else
@@ -244,7 +242,10 @@ static char *get_extension(char *pathname)
       }
    extension = p = strdup(p + 1);
    while (*p)
-      *p++ = tolower(*p);
+      {
+      char c = tolower(*p);
+      *p++ = c;
+      }
    return extension;
    }
 
@@ -270,6 +271,7 @@ static void *xlplayer_main(struct xlplayer *self)
                self->playmode = PM_EJECTING;
             else
                {
+               xlplayer_set_fadesteps(self, self->fade_mode);
                self->jack_flush = TRUE;
                while (self->jack_is_flushed == 0 && *(self->jack_shutdown_f) == FALSE)
                   usleep(10000);
@@ -291,6 +293,7 @@ static void *xlplayer_main(struct xlplayer *self)
             continue;
          case PM_INITIATE:
             self->initial_audio_context = -1;	/* pre-select failure return code */
+            xlplayer_set_fadesteps(self, self->fade_mode);
             extension = get_extension(self->pathname);
             if (
 	            ((!strcmp(extension, "ogg") || !strcmp(extension, "oga")) && oggdecode_reg(self))
@@ -301,12 +304,9 @@ static void *xlplayer_main(struct xlplayer *self)
 		    || (!strcmp(extension, "flac") && flacdecode_reg(self))
 #endif
 		    || ((!strcmp(extension, "wav") || !strcmp(extension, "au") || !strcmp(extension, "aiff")) && sndfiledecode_reg(self))
-#ifdef HAVE_FAAD
-           	    || ((!strcmp(extension, "m4a") || !strcmp(extension, "mp4")) && mp4decode_reg(self))
-#endif
 #ifdef HAVE_AVCODEC
 #ifdef HAVE_AVFORMAT
-                    || ((!strcmp(extension, "m4a") || !strcmp(extension, "mp4") || !strcmp(extension, "wma") || !strcmp(extension, "avi") || !strcmp(extension, "mpc") || !strcmp(extension, "ape")) && avcodecdecode_reg(self))
+                    || ((!strcmp(extension, "m4a") || !strcmp(extension, "mp4") || !strcmp(extension, "m4b") || !strcmp(extension, "m4p") || !strcmp(extension, "wma") || !strcmp(extension, "avi") || !strcmp(extension, "mpc") || !strcmp(extension, "ape")) && avcodecdecode_reg(self))
 #endif /* HAVE_AVFORMAT */
 #endif /* HAVE_AVCODEC */
        		    || (!strcmp(extension, "mp3") && have_mad && mp3decode_reg(self))
@@ -318,7 +318,7 @@ static void *xlplayer_main(struct xlplayer *self)
                self->pause = 0;
                self->samples_written = 0;
                self->sleep_samples = 0;
-               self->fadein_index = self->seek_s ? 0 : -1;
+               self->fadein_index = (self->seek_s || self->fade_mode) ? fb_size - 1 : -1;
                self->dec_init(self);
                if (self->command != CMD_COMPLETE)
                   ++self->current_audio_context;
@@ -336,6 +336,7 @@ static void *xlplayer_main(struct xlplayer *self)
                self->dec_play(self);
             break;
          case PM_EJECTING:
+            xlplayer_set_fadesteps(self, self->fade_mode);
             self->dec_eject(self);
             if (self->playlistmode)
                {
@@ -525,6 +526,7 @@ struct xlplayer *xlplayer_create(int samplerate, double duration, char *playerna
    self->pause = 0;
    self->jack_flush = self->jack_is_flushed = 0;
    self->fadeindex = -1;
+   self->fade_mode = 0;
    self->fadeout_f = 0;
    self->fadein_index = -1;
    self->dither = 0;
@@ -540,6 +542,9 @@ struct xlplayer *xlplayer_create(int samplerate, double duration, char *playerna
    self->up = FALSE;
    self->pbspeed = 1.0F;
    self->pbs_exchange = 0;
+   self->samples_written = 0;
+   self->seek_s = 0;
+   self->play_progress_ms = 0;
    self->dynamic_metadata.data_type = DM_NONE_NEW;
    self->dynamic_metadata.artist = NULL;
    self->dynamic_metadata.title = NULL;
@@ -671,14 +676,20 @@ void xlplayer_dither(struct xlplayer *self, int dither_f)
  
 void xlplayer_eject(struct xlplayer *self)
    {
-   if (self->playmode == PM_PLAYING)
-      {
-      if (!self->fadeout_f)
-         xlplayer_pause(self);
-      self->command = CMD_EJECT;
-      while (self->command)
-         usleep(10000);
-      }
+   if (!self->fadeout_f)
+      xlplayer_pause(self);
+   self->command = CMD_EJECT;
+   while (self->command)
+      usleep(10000);
+   }
+
+void xlplayer_set_fadesteps(struct xlplayer *self, int fade_mode)
+   {
+   static int a[] = { 10, 2, 1 };
+   static int b[] = { 200, 2, 1 };
+
+   self->fadeoutstep = a[fade_mode];
+   self->fadeinstep = b[fade_mode];
    }
 
 /* version supporting playback speed variance */
@@ -840,31 +851,6 @@ size_t read_from_player(struct xlplayer *self, sample_t *left_buf, sample_t *rig
    xlplayer_update_progress_time_ms(self);
    return todo;
    }
-   
-int xlplayer_create_fadein_lookup(float size_seconds, int samplerate)
-   {
-   uint32_t i;
-   sample_t ratio;
-   
-   fadeinlookuptable_numsamples = (size_t)(size_seconds * (float)samplerate);
-   
-   if (!(fadeinlookuptable = malloc(fadeinlookuptable_numsamples * sizeof (sample_t))))
-      return FALSE;
-
-   for (i = 0; i < fadeinlookuptable_numsamples; i++)
-      {
-      ratio = ((sample_t)i) / ((sample_t)fadeinlookuptable_numsamples); /* ranges 0 -> 1 */
-      fadeinlookuptable[i] = powf(10.0F, ((ratio - 1.0F) * 99.0F) / 20.0F);	/* ranges -99 to 0db */
-      }
-   return TRUE;
-   }
-   
-/* xlplayer_destroy_fadein_lookup: frees the lookup table used for fading */
-void xlplayer_destroy_fadein_lookup()
-   {
-   if (fadeinlookuptable)
-      free(fadeinlookuptable);
-   }
 
 void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t type, char *artist, char *title, char *artist_title, int usedelay)
    {
