@@ -79,7 +79,10 @@ struct xlplayer
    int playlistsize;			/* the number of tracks in the playlist */
    jack_default_audio_sample_t *leftbuffer;	/* the output buffers */
    jack_default_audio_sample_t *rightbuffer;
+   int fade_mode;                       /* deferred fade mode */
    int fadeout_f;			/* flag indicated if fade is applied upon stopping */
+   int fadeoutstep;                     /* affects the fade out speed */
+   int fadeinstep;                      /* affects the fade in speed */
    int jack_flush;			/* tells the jack callback to flush the ringbuffers */
    int jack_is_flushed;			/* indicates true when jack callback has done the flush */
    int samplerate;			/* the audio sample rate in use by the jack transport */
@@ -170,13 +173,6 @@ size_t read_from_player(struct xlplayer *self, jack_default_audio_sample_t *left
 /* this is meant to be run inside the jack callback */
 size_t read_from_player_sv(struct xlplayer *self, jack_default_audio_sample_t *left_buf, jack_default_audio_sample_t *right_buf, jack_default_audio_sample_t *left_fbuf, jack_default_audio_sample_t *right_fbuf, jack_nframes_t nframes);
 
-/* xlplayer_create_fadein_lookup: creates the lookup table used for song fadein */
-/* must be called before starting any of the players */
-int xlplayer_create_fadein_lookup(float size_seconds, int samplerate);
-
-/* xlplayer_destroy_fadein_lookup: frees the lookup table used for fading */
-void xlplayer_destroy_fadein_lookup(void);
-
 /* calculate the gain for fading in - used when seeking to prevent clicks */
 jack_default_audio_sample_t xlplayer_get_next_gain(struct xlplayer *self);
 
@@ -192,4 +188,7 @@ void xlplayer_write_channel_data(struct xlplayer *self);
 /* provide data for sending back to the user interface */
 void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t type, char *artist, char *title, char *artist_title, int usedelay);
 
+/* this sets the speed of fading for a particular mode */
+void xlplayer_set_fadesteps(struct xlplayer *self, int fade_step);
+
 #endif /* XLPLAYER_H */
