@@ -545,6 +545,7 @@ class mixprefs:
             print "error creating file 'do-not-ask-profile'"
 	 
    def load_player_prefs(self):
+      proktogglevalue = False
       try:
          file = open(self.parent.idjc + "playerdefaults", "r")
 	 
@@ -562,7 +563,10 @@ class mixprefs:
 	    elif value == "False":
 	       value = False
 	    if self.playersettingsdict.has_key(key):
-	       self.playersettingsdict[key].set_active(value)
+               if key == "proktoggle":
+                  proktogglevalue = value
+               else:
+	          self.playersettingsdict[key].set_active(value)
 	    elif self.valuesdict.has_key(key):
 	       self.valuesdict[key].set_value(float(value))
 	    elif self.textdict.has_key(key):
@@ -570,6 +574,8 @@ class mixprefs:
 	 file.close()
       except IOError:
          print "Failed to read playerdefaults file"
+      if proktogglevalue:
+         self.playersettingsdict["proktoggle"].set_active(True)
       self.parent.send_new_mixer_stats()
 	 
    def apply_player_prefs(self):
@@ -664,7 +670,7 @@ class mixprefs:
             data[1].show()
 	 else:
 	    data[1].hide()
-      if self.mic_peak_toggle.get_active() or self.stream_peak_toggle.get_active() or self.vu_toggle.get_active() or self.limiter_toggle.get_active():
+      if self.mic_peak_toggle.get_active() or self.stream_peak_toggle.get_active() or self.vu_toggle.get_active() or self.limiter_toggle.get_active() or self.stream_status_toggle.get_active():
          if self.parent.simplemixer == False:
             self.parent.meterbox.show()
       else:
@@ -951,11 +957,6 @@ class mixprefs:
       self.dither.show()
       parent.tooltips.set_tip(self.dither, ln.dither_tip)
 
-      self.keeppass = gtk.CheckButton(ln.keeppass)
-      vbox.pack_start(self.keeppass, False, False, 0)
-      self.keeppass.show()
-      parent.tooltips.set_tip(self.keeppass, ln.keep_password_tip)
-
       self.mp3_utf8 = gtk.CheckButton(ln.mp3_utf8)
       self.mp3_utf8.set_active(True)
       vbox.pack_start(self.mp3_utf8, False, False, 0)
@@ -982,6 +983,7 @@ class mixprefs:
       # Reconnection dialog config
       
       self.recon_config = ReconnectionDialogConfig()
+      parent.tooltips.set_tip(self.recon_config, ln.recon_tip)
       outervbox.pack_start(self.recon_config, False, False, 0)
       self.recon_config.show()
       
@@ -1239,7 +1241,7 @@ class mixprefs:
       self.lstream.set_active(True)
       lvbox.add(self.lstream)
       self.lstream.show()
-      self.llisten = gtk.CheckButton(ln.listen)
+      self.llisten = gtk.CheckButton(ln.djlisten)
       self.llisten.set_border_width(1)
       self.llisten.set_active(True)
       lvbox.add(self.llisten)
@@ -1289,7 +1291,7 @@ class mixprefs:
       self.rstream.set_active(True)
       rvbox.add(self.rstream)
       self.rstream.show()
-      self.rlisten = gtk.CheckButton(ln.listen)
+      self.rlisten = gtk.CheckButton(ln.djlisten)
       self.rlisten.set_border_width(1)
       self.rlisten.set_active(True)
       rvbox.add(self.rlisten)
@@ -1947,7 +1949,6 @@ class mixprefs:
          "normalize"	 : self.normalize,
          "dither"	 : self.dither,
          "recallsession" : self.restore_session_option,
-         "keeppass"      : self.keeppass,
          "proktoggle"    : self.p3prefs.proktoggle,
          "ee_appstart"	 : self.appstart_event,
          "ee_appexit"    : self.appexit_event,
