@@ -20,12 +20,18 @@
 
 about_tab = "About"
 
+add = "Add"
+
 add_file = "Add Music"
 
 add_to_jingles = "Add To Jingles"
 
 add_track_tip = "Add tracks to the playlist."
 
+admin_passwd = "Admin:"
+
+admin_tip = "Set this if you know the administrator password for the server and need it to obtain listener stats, otherwise leave it blank. The stats login will be assumed to be 'admin' if you set this."
+
 advance_tip = "This button either starts the currently highlighted track playing or stops the currently playing one and highlights the next track."
 
 agc_compressor = "Compressor"
@@ -210,12 +216,34 @@ comp_release = "Release"
 
 compression_meter_tip = "A meter indicating the current amount of attenuation being applied to each microphone input by the compressor."
 
+conn_col_type = "Type"
+
+conn_col_host = "Hostname/IP"
+
+conn_col_port = "Port"
+
+conn_col_mount = "Mount point"
+
+conn_col_listeners = "Listeners"
+
 connected_to_history = "connected to"
 
 connection = " Connection "
 
 connection_lost = "Connection Lost"
 
+connection_undefined = " Connection "
+
+connection_icecast2 = " Connection: Icecast 2 server "
+
+connection_shoutcast = " Connection: Shoutcast server "
+
+connections_table_tip = "A table of servers with which to connect. Only one master server can be added for the purpose of streaming. All other servers will appear below the master server in the list for the purpose of stats collection which can be toggled on a per server basis by the check button in the left hand column. The type column consists of a code pertaining to the type of server: Icecast2/Shoutcast, Master/Relay."
+
+connections_add_tip = "Click this to add server information from the entry boxes below into the table above. Fields below cannot be left blank or else nothing will happen."
+
+connections_editremove_tip = "Click this when you want to remove a server from the list above for editing/removal. Highlight the particular server first. The information will be transferred to the entry boxes below."
+
 contact_info = " Shoutcast Contact Info "
 
 contrib_label = "Contributors"
@@ -346,6 +374,8 @@ duplicate = "Duplicate"
 
 elapsed_recording = "Elapsed:"
 
+edit_remove = "Edit/Remove"
+
 empty = "Empty"
 
 enable = "Enable"
@@ -384,6 +414,12 @@ external_playlist = "Choose a playlist file."
 
 external_directory = "Choose a folder/directory of music."
 
+fade_none_menu = "No Fade"
+
+fade_5_menu = "Fade 5s"
+
+fade_10_menu = "Fade 10s"
+
 fadeout_toggle = "Fadeout"
 
 fall = "Fall"
@@ -428,12 +464,24 @@ fully_featured = "Fully Featured"
 
 fully_featured_tip = "Run in full functionality mode which uses more CPU power."
 
+gather_stats = "Obtain listener stats"
+
+gather_stats_tip = "Setting this will cause IDJC to attempt to obtain the number of listeners from the server and display the sum total number of listeners in the main application window and the individual server listener count to the left."
+
 general_tab = "General"
 
 genre = "Genre:"
 
 genre_tip = "The musical genres you are likely to play."
 
+get_stats = "Get listener stats:"
+
+get_stats_never = "Never"
+
+get_stats_always = "Always"
+
+get_stats_ifconnected = "If connected"
+
 good_quality_resample = "Good"
 
 green_phone_tip = "Mix voice over IP audio to the output stream."
@@ -466,6 +514,29 @@ icy_irc_tip = "Internet Relay Chat connection info goes here."
 
 id3_tag = "ID3 Tag"
 
+id3title = "title"
+
+id3artist = "artist"
+
+id3album = "album"
+
+id3track = "track/total"
+
+id3genre = "genre"
+
+id3recorddate = "record date"
+
+id3textframes = " Additional Text Frames "
+
+id3freeform = """Add any other ID3 text frames here.
+e.g. TIT2:Alternate Title
+This will be appended onto the main TIT2 tag.
+
+Enter user defined text frames like this:
+TXXX:foo=bar
+
+For more information visit www.id3.org."""
+
 idjc_launch_failed = "IDJC Launch Failed"
 
 idjc_shutdown = "IDJC Shutdown"
@@ -527,12 +598,16 @@ jingles_window = "IDJC Jingles"
 
 jingles_window_open_tip = "Open the jingles player window."
 
-keep_password_tip = "Choosing this option will cause the server passwords to be saved to the IDJC configuration file so they will be there when you next restart IDJC. If this is a security concern to you it would be wise to keep this feature turned off. Those doing so will have to type in their server passwords each time IDJC is run."
-
-keeppass = "Remember server passwords (potential security risk)"
-
 l = "L"
 
+label_icecast_master = "Icecast 2 Master"
+
+label_icecast_relay = "Icecast 2 Stats/Relay"
+
+label_shoutcast_master = "Shoutcast Master"
+
+label_shoutcast_relay = "Shoutcast Stats/Relay"
+
 latency = "Latency:"
 
 left = "Left:"
@@ -549,9 +624,11 @@ licence = "Released under the GNU General Public License V3.0"
 
 licence_tab = "Licence"
 
-listen = " Listen "
+audiofeed = " Audio Feed "
 
-listener_indicator_tip = "The combined total number of listeners some time in the last thirty seconds."
+djlisten = " DJ "
+
+listener_indicator_tip = "The combined total number of listeners in all server tabs."
 
 listen_tip = "Make output from this player audible to the DJ."
 
@@ -559,11 +636,17 @@ listen_url = "Listen URL:"
 
 listen_url_tip = "The URL of your radio station. This and the rest of the information below is intended for display on a radio station listings website."
 
+listeners_failed = "Failed"
+
+listeners_unknown = "Unknown"
+
+listeners_total_tip = "The sum total of listeners in this server tab."
+
 lmic_toggle_tip = "This button toggles the left microphone input."
 
 localhost = "Localhost"
 
-login_tip = "Icecast servers can be configured to have individual per-user source passwords to facilitate efficient password revocation. This requires that every user must have a separate login name which is entered here. The default login name is 'source'."
+login_tip = "Icecast servers require a login password. On a server where no fixed mountpoints have been configured the source login will be 'source'. For collecting stats the admin password can be given for which the login is by default, 'admin' but could have been changed to something else. Stats may be collected with a source login provided the mountpoint matches."
 
 loop_all = "Loop All"
 
@@ -677,6 +760,20 @@ mp3_utf8 = "Use utf-8 encoding when streaming mp3 metadata"
 
 mp3_utf8_tip = "It is standard practice when streaming metadata in mp3 streams to use iso-8859-1 character encoding. This is unfortunate since with utf-8 practically anything can be encoded. In deciding whether to use this feature you have to consider the proportion of listener clients that will be capable of correctly decoding text encoded with utf-8."
 
+mp4title = "Title"
+
+mp4artist = "Artist"
+
+mp4album = "Album"
+
+mp4track = "Track"
+
+mp4genre = "Genre"
+
+mp4year = "Year"
+
+native = "Native"
+
 new_profile_body = """Profile '%s' does
 not currently exist.
 Would you like to create it?"""
@@ -729,6 +826,8 @@ normfall = "Fall"
 
 normrise = "Rise"
 
+not_connected = "Not Connected"
+
 off = "Off"
 
 ogg_streamtab_tip = "Clicking this tab selects the Ogg family of file formats."
@@ -747,12 +846,16 @@ pass_button_tip = "This button causes the crossfader to move to the opposite sid
 
 pass_speed_tip = "The time in seconds that the crossfader will take to automatically pass across when the button to the right is clicked."
 
-password_tip = "The server password goes here."
+password_tip = "The password matching the above login goes here. For collecting listener stats on Shoutcast servers the password needs to be the admin password whenever an admin password is set on the server."
 
 pause_rec_tip = "Pause recording."
 
 pause_tip = "Pause."
 
+pldelay_none = "None"
+
+pldelay_tip = "This controls the amount of fade between tracks."
+
 play_all = "Play All"
 
 play_jingles_tip = "Play the jingles sequence specified above or if none is specified play the jingle highlighted in the playlist. The volume level of the main media players will be reduced somewhat for the duration."
@@ -811,6 +914,10 @@ playlisttype_header1 = "File Type"
 
 playlisttype_header2 = "Extension"
 
+playlistmode = "Playlist Mode"
+
+populating = "Populating"
+
 popupwindowplayduration = "Total play duration %s"
 
 popupwindowplaying = "Playing track %d of %d"
@@ -819,7 +926,7 @@ popupwindowtracktotal = "Total number of tracks %d"
 
 port = "Port"
 
-port_tip = "The network port number which the server is using. Frequently it is 8000."
+port_tip = "The base port number which the server is using."
 
 prefs_button = "Prefs"
 
@@ -883,6 +990,12 @@ rec_directory_tip = "Choose which directory you want to save to. All file names
 
 rec_source_tip = "Chooses which stream to record. If the stream isn't running the encoder will be started for you. Remember to make sure the encoder settings are to your liking before you start recording."
 
+recon_tip = """A set of controls for managing what happens when the server connection either breaks or suffers prolonged congestion.
+ 
+The 'delays of' control consists of a comma separated list of time delays for the reconnection dialog. When the list is exhausted further attempts to reconnect to the server are abandoned, so three numbers denote a maximum three reconnection attempts.
+
+You also have the option to attempt reconnection when the stream buffer becomes full. Use this option if waiting out the congestion is not helpful."""
+
 reconnected = "IDJC Reconnected"
 
 reconnected_additional = ('Automatically reconnected to the server', 'after the server module crashed')
@@ -987,7 +1100,12 @@ server_type_icecast2 = "Icecast 2"
 
 server_type_shoutcast = "Shoutcast"
 
-server_type_tip = "IDJC can connect to both Icecast and Shoutcast servers. For this to be successful you need to specify the type of server that you wish to connect to since each type has a different connection protocol."
+server_type_tip = "IDJC can connect to both Icecast and Shoutcast servers. For connection to be successful you need to specify the type of server that you wish to connect to. Also note, you can specify a relay here for the purpose of stats collection. If a master has already been added to the list above you can't add another one - to stream to more than one server use a different server tab instead."
+
+server_type_codes = ("I2M", "SM", "I2R", "SR")
+
+server_type_labels = ("Icecast 2 Master", "Shoutcast Master",
+                      "Icecast 2 Stats/Relay", "Shoutcast Stats/Relay")
 
 server_window = "Radio Server"
 
@@ -1159,6 +1277,8 @@ track_announcer = "Track Announcer"
 
 track_announcer_latency_tip = "A delay to the displaying of the change of track information in IRC. The idea is to match this number to the average audio latency in seconds that the listeners will be experiencing. Ten to fifteen seconds typically."
 
+trackfade = "Fade"
+
 track_history_clear = "Remove Contents"
 
 tracks_played = "Tracks Played"
